==> openlucius-7.x-1.0.tar.gz: openlucius/themes/openlucius/theme/page/page.tpl.php <==
<?php
/**
 * @file
 * Default theme implementation to display a single Drupal page.
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template in this directory.
 * Available variables:
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 * @see bootstrap_preprocess_page()
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see bootstrap_process_page()
 * @see template_process()
 * @see html.tpl.php
 * @ingroup themeable
 */
?>

<?php if (!empty($page['navigation'])): ?>
  <?php print render($page['navigation']); ?>
<?php endif; ?>

<?php print render($page['header']); ?>

<div class="main-container container">
  <header role="banner" id="page-header">
    <?php if (!empty($site_slogan)): ?>
      <p class="lead"><?php print $site_slogan; ?></p>
    <?php endif; ?>
  </header>
  <!-- /#page-header -->

  <?php if (!empty($page['content_top'])): ?>
    <div class="row">
      <div class="col-lg-12">
        <?php print render($page['content_top']); ?>
      </div>
    </div>
  <?php endif; ?>

  <div class="row">
    <?php if (!empty($page['sidebar_first'])): ?>
      <aside class="col-sm-3 hidden-sm hidden-xs" role="complementary">
        <?php print render($page['sidebar_first']); ?>
      </aside>  <!-- /#sidebar-first -->
    <?php endif; ?>

    <section<?php print $content_column_class; ?>>
      <?php if (!empty($page['highlighted'])): ?>
        <div class="highlighted jumbotron"><?php print render($page['highlighted']); ?></div>
      <?php endif; ?>

      <?php if (!empty($breadcrumb)): print $breadcrumb; endif; ?>
      <a id="main-content"></a>
      <?php print render($title_prefix); ?>

      <?php if (!empty($title) && !isset($hide_header)): ?>
      <h1 class="page-header">
        <?php if (isset($node_icon)): ?>
          <span class="glyphicon glyphicon-<?php print ($node_icon); ?>"></span>
        <?php endif; ?>
        <?php if (!empty($username)): ?>
          <?php print $username; ?>
        <?php endif; ?>
        <?php print $title; ?>
      </h1>
      <?php endif; ?>
      <?php if (isset($print_tabs)) : ?>
        <?php if ($tabs = render($tabs)): ?><div class="tabs"><?php print $tabs; ?></div><?php endif; ?>
      <?php endif; ?>
      <?php print render($title_suffix); ?>
      <?php print $messages; ?>
      <?php if (!empty($page['help'])): ?>
        <?php print render($page['help']); ?>
      <?php endif; ?>
      <?php if (!empty($action_links)): ?>
        <ul class="action-links"><?php print render($action_links); ?></ul>
      <?php endif; ?>

      <?php if (isset($add_file_link)): ?>
        <?php print $add_file_link; ?>
      <?php endif; ?>

      <?php print render($page['content']); ?>
    </section>

    <?php if (!empty($page['sidebar_second'])): ?>
      <aside id="side-overlay" class="col-sm-3" role="complementary">
        <div id="side-overlay-scroll">

          <div class="side-header side-content hidden-md hidden-lg">
            <button class="btn btn-default btn-xs pull-right" type="button" data-toggle="layout" data-action="side_overlay_close">
              <span class="glyphicon glyphicon-chevron-right"></span>
            </button>
          </div>

          <?php if (!empty($page['sidebar_second'])): ?>
            <?php print render($page['sidebar_second']); ?>
          <?php endif; ?>

        </div>
      </aside>
    <?php endif; ?>

  </div>
</div>

<footer class="footer container">
  <div class="text-center footer-styling"><?php print t('Powered by') . ' '; ?><a href="http://www.openlucius.com">OpenLucius</a> | <?php print l(t('Help'), 'http://help.openlucius.com/content/please-choose-manual', array('attributes' => array('target'=>'_blank'))); ?></div>
  <?php print render($page['footer']); ?>
</footer>

==> openlucius-7.x-1.3.tar.gz: openlucius/themes/openlucius/theme/page/page.tpl.php <==
<?php
/**
 * @file
 * Default theme implementation to display a single Drupal page.
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template in this directory.
 * Available variables:
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 * @see bootstrap_preprocess_page()
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see bootstrap_process_page()
 * @see template_process()
 * @see html.tpl.php
 * @ingroup themeable
 */
?>

<?php if (!empty($page['navigation'])): ?>
  <?php print render($page['navigation']); ?>
<?php endif; ?>

<?php print render($page['header']); ?>

<div class="main-container container">
  <header role="banner" id="page-header">
    <?php if (!empty($site_slogan)): ?>
      <p class="lead"><?php print $site_slogan; ?></p>
    <?php endif; ?>
  </header>
  <!-- /#page-header -->

  <?php if (!empty($page['content_top'])): ?>
    <div class="row">
      <div class="col-lg-12">
        <?php print render($page['content_top']); ?>
      </div>
    </div>
  <?php endif; ?>

  <div class="row">
    <?php if (!empty($page['sidebar_first'])): ?>
      <aside class="col-sm-3 hidden-sm hidden-xs" role="complementary">
        <?php print render($page['sidebar_first']); ?>
      </aside>  <!-- /#sidebar-first -->
    <?php endif; ?>

    <section<?php print $content_column_class; ?>>
      <?php if (!empty($page['highlighted'])): ?>
        <div class="highlighted jumbotron"><?php print render($page['highlighted']); ?></div>
      <?php endif; ?>

      <?php if (!empty($breadcrumb)): print $breadcrumb; endif; ?>
      <a id="main-content"></a>
      <?php print render($title_prefix); ?>

      <?php if (!empty($title) && !isset($hide_header)): ?>
      <h1 class="page-header">
        <?php if (isset($node_icon)): ?>
          <span class="glyphicon glyphicon-<?php print ($node_icon); ?>"></span>
        <?php endif; ?>
        <?php if (!empty($username)): ?>
          <?php print $username; ?>
        <?php endif; ?>
        <?php print $title; ?>
        <?php if (!empty($heading_local_tasks)): ?>
          <span class="group-local-tasks-wrapper">
            <?php print $heading_local_tasks; ?>
          </span>
        <?php endif; ?>
      </h1>
      <?php endif; ?>
      <?php if (isset($print_tabs)) : ?>
        <?php if ($tabs = render($tabs)): ?>
          <div class="tabs"><?php print $tabs; ?></div>
        <?php endif; ?>
      <?php endif; ?>
      <?php print render($title_suffix); ?>
      <?php print $messages; ?>
      <?php if (!empty($page['help'])): ?>
        <?php print render($page['help']); ?>
      <?php endif; ?>
      <?php if (!empty($action_links)): ?>
        <ul class="action-links"><?php print render($action_links); ?></ul>
      <?php endif; ?>

      <?php if (isset($add_file_link)): ?>
        <?php print $add_file_link; ?>
      <?php endif; ?>

      <?php print render($page['content']); ?>
    </section>

    <?php if (!empty($page['sidebar_second'])): ?>
      <aside id="side-overlay" class="col-sm-3" role="complementary">
        <div id="side-overlay-scroll">

          <div class="side-header side-content hidden-md hidden-lg">
            <button class="btn btn-default btn-xs pull-right" type="button" data-toggle="layout" data-action="side_overlay_close">
              <span class="glyphicon glyphicon-chevron-right"></span>
            </button>
          </div>

          <?php if (!empty($page['sidebar_second'])): ?>
            <?php print render($page['sidebar_second']); ?>
          <?php endif; ?>

        </div>
      </aside>
    <?php endif; ?>

  </div>
</div>

<footer class="footer container">
  <div class="text-center footer-styling"><?php print t('Powered by') . ' '; ?><a href="http://www.openlucius.com">OpenLucius</a> | <?php print l(t('Help'), 'http://help.openlucius.com/content/please-choose-manual', array('attributes' => array('target'=>'_blank'))); ?></div>
  <?php print render($page['footer']); ?>
</footer>
